Method: Warframe::Client#get

Defined in:
lib/warframe/client.rb

#get(path, klass) ⇒ Object

Performs a get operation on the requested path, and returns a mapped response of the requested model.

Parameters:



68
69
70
71
72
73
# File 'lib/warframe/client.rb', line 68

def get(path, klass)
  return get_from_cache(path) if find_in_cache(path)

  result = get_request(path, klass)
  add_to_cache(path, result)
end